.. image:: https://travis-ci.org/jeremiedecock/sportmg.svg?branch=master
    :target: https://travis-ci.org/jeremiedecock/sportmg

========
Sport-mg
========

Copyright (c) 2015-2018 Jeremie DECOCK (http://www.jdhp.org)

* Web site: http://www.jdhp.org/projects_en.html
* Source code: https://github.com/jeremiedecock/sportmg
* Issue tracker: https://github.com/jeremiedecock/sportmg/issues
* Sport-mg on PyPI: https://pypi.python.org/pypi/sportmg
* Sport-mg on Anaconda Cloud: https://anaconda.org/jdhp/sportmg


Description
===========

Sport-mg is an open source tool to manage sports sessions.

.. warning::

    This project is in beta stage.


Dependencies
============

- Python >= 3.0
- Qt5 for Python
- Pandas


.. _install:

Installation
============

Gnu/Linux
---------

You can install, upgrade, uninstall Sport-mg with these commands (in a
terminal)::

    pip install --pre sportmg
    pip install --upgrade sportmg
    pip uninstall sportmg

Or, if you have downloaded the Sport-mg source code::

    python3 setup.py install

.. There's also a package for Debian/Ubuntu::
.. 
..     sudo apt-get install sportmg

Windows
-------

.. Note:
.. 
..     The following installation procedure has been tested to work with Python
..     3.4 under Windows 7.
..     It should also work with recent Windows systems.

You can install, upgrade, uninstall Sport-mg with these commands (in a
`command prompt`_)::

    py -m pip install --pre sportmg
    py -m pip install --upgrade sportmg
    py -m pip uninstall sportmg

Or, if you have downloaded the Sport-mg source code::

    py setup.py install

MacOSX
-------

Note:

    The following installation procedure has been tested to work with Python
    3.5 under MacOSX 10.9 (*Mavericks*).
    It should also work with more recent MacOSX systems.

You can install, upgrade, uninstall Sport-mg with these commands (in a
terminal)::

    pip install --pre sportmg
    pip install --upgrade sportmg
    pip uninstall sportmg

Or, if you have downloaded the Sport-mg source code::

    python3 setup.py install

Sport-mg requires Qt5 and its Python 3 bindings plus few additional
libraries to run.

.. These dependencies can be installed using MacPorts::
.. 
..     port install gtk3
..     port install py35-gobject3
..     port install py35-matplotlib

.. or with Hombrew::
.. 
..     brew install gtk+3
..     brew install pygobject3


Bug reports
===========

To search for bugs or report them, please use the Sport-mg Bug Tracker at:

    https://github.com/jeremiedecock/sportmg/issues


License
=======

This project is provided under the terms and conditions of the
`MIT License`_.

.. _MIT License: http://opensource.org/licenses/MIT
.. _Sport-mg: https://github.com/jeremiedecock/sportmg
.. _command prompt: https://en.wikipedia.org/wiki/Cmd.exe
